server/hook.py
changeset 9283 5f2c5eb1a820
parent 9257 ce338133c92c
parent 9267 24d9b86dfa54
child 9340 b1e933b0e850
--- a/server/hook.py	Wed Oct 09 11:13:56 2013 +0200
+++ b/server/hook.py	Thu Oct 10 13:26:11 2013 +0200
@@ -41,7 +41,7 @@
 defined over data events.
 
 Also, some :class:`~cubicweb.server.hook.Operation` may be registered by hooks,
-which will be fired when the transaction is commited or rollbacked.
+which will be fired when the transaction is commited or rolled back.
 
 The purpose of data event hooks is usually to complement the data model as
 defined in the schema, which is static by nature and only provide a restricted
@@ -705,10 +705,10 @@
 
     * `rollback`:
 
       the transaction has been either rollbacked either:
 
        * intentionaly
        * a 'precommit' event failed, in which case all operations are rollbacked
          once 'revertprecommit'' has been called
 
     * `postcommit`:
@@ -770,7 +770,7 @@
         """
 
     def rollback_event(self):
         """the observed connections set has been rollbacked
 
         do nothing by default
         """
@@ -1034,7 +1034,7 @@
     type/source cache eids of entities added in that transaction.
 
     NOTE: querier's rqlst/solutions cache may have been polluted too with
     queries such as Any X WHERE X eid 32 if 32 has been rollbacked however
     generated queries are unpredictable and analysing all the cache probably
     too expensive. Notice that there is no pb when using args to specify eids
     instead of giving them into the rql string.
@@ -1042,7 +1042,7 @@
     data_key = 'neweids'
 
     def rollback_event(self):
         """the observed connections set has been rollbacked,
         remove inserted eid from repository type/source cache
         """
         try:
@@ -1056,7 +1056,7 @@
     """
     data_key = 'pendingeids'
     def postcommit_event(self):
         """the observed connections set has been rollbacked,
         remove inserted eid from repository type/source cache
         """
         try:
@@ -705,10 +705,10 @@
     * `rollback`:
 
-      the transaction has been either rollbacked either:
+      the transaction has been either rolled back either:
 
        * intentionaly
@@ -705,10 +705,10 @@
 
        * intentionaly
-       * a 'precommit' event failed, in which case all operations are rollbacked
+       * a 'precommit' event failed, in which case all operations are rolled back
          once 'revertprecommit'' has been called
 
@@ -770,7 +770,7 @@
 
     def rollback_event(self):
-        """the observed connections set has been rollbacked
+        """the observed connections set has been rolled back
 
         do nothing by default
@@ -1034,7 +1034,7 @@
 
     NOTE: querier's rqlst/solutions cache may have been polluted too with
-    queries such as Any X WHERE X eid 32 if 32 has been rollbacked however
+    queries such as Any X WHERE X eid 32 if 32 has been rolled back however
     generated queries are unpredictable and analysing all the cache probably
     too expensive. Notice that there is no pb when using args to specify eids
@@ -1042,7 +1042,7 @@
 
     def rollback_event(self):
-        """the observed connections set has been rollbacked,
+        """the observed connections set has been rolled back,
         remove inserted eid from repository type/source cache
         """
@@ -1056,7 +1056,7 @@
     data_key = 'pendingeids'
     def postcommit_event(self):
-        """the observed connections set has been rollbacked,
+        """the observed connections set has been rolled back,
         remove inserted eid from repository type/source cache
         """